@@ -16,6 +16,7 @@
 #include "directoryserviceswidget.h"
 #include "filenamerequester.h"
 
+#include <libkleo/compliance.h>
 #include <libkleo/formatting.h>
 #include <libkleo/gnupg.h>
 #include <libkleo/keyserverconfig.h>
@@ -47,7 +48,6 @@
 #include <QSpinBox>
 #include <QStyle>
 #include <QVBoxLayout>
-#include <QWindow>
 
 #include <gpgme.h>
 
@@ -386,7 +386,7 @@ bool offerEntryForConfiguration(QGpgME::CryptoConfigEntry *entry)
         }
     }
 
-    const bool de_vs = Kleo::gnupgUsesDeVsCompliance();
+    const bool de_vs = DeVSCompliance::isActive();
     // Skip "dangerous" expert options if we are running in CO_DE_VS.
     // Otherwise, skip any options beyond "invisible" (== expert + 1) level.
     const auto maxEntryLevel = de_vs ? QGpgME::CryptoConfigEntry::Level_Advanced //
@@ -993,7 +993,7 @@ void prepareURLCfgDialog(QDialog *dialog, DirectoryServicesWidget *dirserv, bool
 void Kleo::CryptoConfigEntryLDAPURL::slotOpenDialog()
 {
     if (!gpgme_check_version("1.16.0")) {
-        KMessageBox::sorry(mPushButton->parentWidget(),
+        KMessageBox::error(mPushButton->parentWidget(),
                            i18n("Configuration of directory services is not possible "
                                 "because the used gpgme libraries are too old."),
                            i18n("Sorry"));
